=======================
 Invenio-Mail v1.0.0b1
=======================

Invenio-Mail v1.0.0b1 was released on December 5, 2016.

About
-----

Invenio mail module.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-mail==1.0.0b1

Documentation
-------------

   https://invenio-mail.readthedocs.io/

Happy hacking and thanks for flying Invenio-Mail.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-mail
|   URL: http://inveniosoftware.org
